@@ -1,20 +1,64 @@
+use strict;
+use warnings;
 package Dancer::Plugin::CORS::Sharing;
+# ABSTRACT: Helper class for I<sharing> method
 
-use Modern::Perl;
 use Carp;
 use Scalar::Util qw(blessed);
 
+our $VERSION = '0.13'; # VERSION
+
+
+sub new($%) {
+	my $class = shift;
+	my %options = (rules => []);
+	if (blessed $class and $class->isa(__PACKAGE__)) {
+		%options = (%$class, %options);
+	}
+	%options = (%options, @_);
+	croak "sharing->new should be called inside a dancer app, not outside" unless exists $options{_add_rule};
+	return bless \%options => ref $class || $class;
+}
+
+
+sub rule($%) {
+	my ($self, %options) = @_;
+	push @{$self->{rules}} => \%options;
+	$self;
+}
+
+
+sub add {
+	my ($self, @routes) = @_;
+	foreach my $routes (@routes) {
+		$routes = [ $routes ] unless ref $routes eq 'ARRAY';
+		foreach my $route (@$routes) {
+			foreach my $options (@{$self->{rules}}) {
+				$self->{_add_rule}->($route, %$options);
+			}
+		}
+	}
+	$self;
+}
+
+
+sub clear {
+	my $self = shift;
+	$self->{rules} = [];
+	$self;
+}
+
+__END__
+
+=pod
+
 =head1 NAME
 
-Dancer::Plugin::CORS::Sharing - Helper class for I<sharing> keyword
+Dancer::Plugin::CORS::Sharing - Helper class for I<sharing> method
 
 =head1 VERSION
 
-Version 0.11
-
-=cut
-
-our $VERSION = '0.11';
+version 0.13
 
 =head1 DESCRIPTION
 
@@ -34,7 +78,7 @@ In order to use many rules with many routes, this helpers class helps you to org
 	sharing->add($route);
 
 =head1 METHODS
-	
+
 =head2 new
 
 A convient way is to use the implicit form of the module. This means you don't have to call new() self, just start with defining rules and add routes.
@@ -44,32 +88,11 @@ When you want more than one ruleset, obtain a new instance by calling new():
 	my $sharing = sharing->new;
 	$sharing->rule(...);
 	$sharing->add(...);
-	
-=cut
-
-sub new($%) {
-	my $class = shift;
-	my %options = (rules => []);
-	if (blessed $class and $class->isa(__PACKAGE__)) {
-		%options = (%$class, %options);
-	}
-	%options = (%options, @_);
-	croak "sharing->new should be called inside a dancer app, not outside" unless exists $options{_add_rule};
-	return bless \%options => ref $class || $class;
-}
 
 =head2 rule(%options)
 
 This method defines a optionset. See L<Dancer::Plugin::CORS::share> for a explaination of valid options.
 
-=cut
-
-sub rule($%) {
-	my ($self, %options) = @_;
-	push @{$self->{rules}} => \%options;
-	$self;
-}
-
 =head2 add(@routes)
 
 This method finally calls L<Dancer::Plugin::CORS::share> for any route. @routes maybe a list of arrayrefs of L<Dancer::Route> objects or paths.
@@ -78,51 +101,39 @@ Note: L<Dancer::Plugin::CRUD::resource> returns a hash instead of a list. Use va
 
 	sharing->add(values(resource(...)));
 
-=cut
-
-sub add {
-	my ($self, @routes) = @_;
-	foreach my $routes (@routes) {
-		$routes = [ $routes ] unless ref $routes eq 'ARRAY';
-		foreach my $route (@$routes) {
-			foreach my $options (@{$self->{rules}}) {
-				$self->{_add_rule}->($route, %$options);
-			}
-		}
-	}
-	$self;
-}
-
 =head2 clear
 
 This method clears all previously defined rules.
 
-=cut
-
-sub clear {
-	my $self = shift;
-	$self->{rules} = [];
-	$self;
-}
-
-=head1 AUTHOR
-
-David Zurborg, C<< <zurborg@cpan.org> >>
-
 =head1 SEE ALSO
 
 =over
 
-=item L<Dancer::Plugin::CORS>
+=item * L<Dancer::Plugin::CORS>
 
 =back
 
-=head1 COPYRIGHT & LICENSE
+1;
 
-Copyright 2014 David Zurborg, all rights reserved.
+=head1 BUGS
 
-This program is released under the following license: open-source
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/zurborg/libdancer-plugin-cors-perl/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 AUTHOR
+
+David Zurborg <zurborg@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2014 by David Zurborg.
+
+This is free software, licensed under:
+
+  The ISC License
 
 =cut
-
-1;
